nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Flags

Struct Flags 

#[repr(transparent)]
pub struct Flags(pub u32);
Wakeup, interrupt, and reset flags

Tuple Fields

0: u32

Implementations

Source

impl Flags

pub const fn porcoref(&self) -> Porcoref

vddcore POR Flag

pub const fn set_porcoref(&mut self, val: Porcoref)

vddcore POR Flag

pub const fn por1v8f(&self) -> Por1v8f

vdd1v8 power on reset flag

pub const fn set_por1v8f(&mut self, val: Por1v8f)

vdd1v8 power on reset flag

pub const fn porao18f(&self) -> Porao18f

vdd_ao18 power on reset flag

pub const fn set_porao18f(&mut self, val: Porao18f)

vdd_ao18 power on reset flag

pub const fn lvdcoref(&self) -> Lvdcoref

vddcore Low-Voltage Detector Flag This flag is set when a low voltage event was detected by the vddcore LVD monitor and it is enabled for interrupt or reset

pub const fn set_lvdcoref(&mut self, val: Lvdcoref)

vddcore Low-Voltage Detector Flag This flag is set when a low voltage event was detected by the vddcore LVD monitor and it is enabled for interrupt or reset

pub const fn hvdcoref(&self) -> Hvdcoref

vddcore High-Voltage Detector Flag This flag is set when a high-voltage event was detected by the vddcore HVD monitor and it is enabled for interrupt or reset

pub const fn set_hvdcoref(&mut self, val: Hvdcoref)

vddcore High-Voltage Detector Flag This flag is set when a high-voltage event was detected by the vddcore HVD monitor and it is enabled for interrupt or reset

pub const fn hvd1v8f(&self) -> Hvd1v8f

vdd1v8 High-Voltage Detector Flag This flag is set when a high-voltage event was detected by the vdd1v8 HVD monitor and it is enabled for interrupt or reset

pub const fn set_hvd1v8f(&mut self, val: Hvd1v8f)

vdd1v8 High-Voltage Detector Flag This flag is set when a high-voltage event was detected by the vdd1v8 HVD monitor and it is enabled for interrupt or reset

pub const fn rtcf(&self) -> Rtcf

RTC Wakeup from deep powerdown mode flag.

pub const fn set_rtcf(&mut self, val: Rtcf)

RTC Wakeup from deep powerdown mode flag.

pub const fn autowkf(&self) -> Autowkf

PMC Auto Wakeup Interrupt flag.

pub const fn set_autowkf(&mut self, val: Autowkf)

PMC Auto Wakeup Interrupt flag.

pub const fn intnpadf(&self) -> Intnpadf

PMIC interrupt pin flag

pub const fn set_intnpadf(&mut self, val: Intnpadf)

PMIC interrupt pin flag

pub const fn resetnpadf(&self) -> Resetnpadf

Reset pad flag

pub const fn set_resetnpadf(&mut self, val: Resetnpadf)

Reset pad flag

pub const fn deeppdf(&self) -> Deeppdf

Deep powerdown wakeup flag

pub const fn set_deeppdf(&mut self, val: Deeppdf)

Deep powerdown wakeup flag